package com.ruoyi.project.business.mapper.quotation;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TqSpecification;
import com.ruoyi.project.business.domain.bo.quotation.QuotationContractBo;
import com.ruoyi.project.business.domain.bo.quotation.SpecificationQueryBO;
import com.ruoyi.project.business.domain.vo.quotation.ElevatorExportVO;
import com.ruoyi.project.business.domain.vo.quotation.H5ElevatorVO;
import com.ruoyi.project.business.domain.vo.quotation.QuotationContractVo;
import com.ruoyi.project.business.domain.vo.quotation.SpecificationVO;
import java.math.BigDecimal;
import java.util.List;
import org.apache.ibatis.annotations.Param;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-10
 */
public interface TqSpecificationMapper extends BaseMapper<TqSpecification> {

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TqSpecification selectTqSpecificationById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tqSpecification 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TqSpecification> selectTqSpecificationList(TqSpecification tqSpecification);

    public List<SpecificationVO> selectSpecificationVOList(SpecificationQueryBO tqSpecification);

    /**
     * 新增【请填写功能名称】
     *
     * @param tqSpecification 【请填写功能名称】
     * @return 结果
     */
    public int insertTqSpecification(TqSpecification tqSpecification);

    /**
     * 修改【请填写功能名称】
     *
     * @param tqSpecification 【请填写功能名称】
     * @return 结果
     */
    public int updateTqSpecification(TqSpecification tqSpecification);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTqSpecificationById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTqSpecificationByIds(Long[] ids);

    void deleteByQuotationId(Long quotationId);

    int updateAuditOptionalPrice(@Param("id") Long specificationId, @Param("price") BigDecimal auditOptionPrice);

    int getCount(Long elevatorModelId);

    List<H5ElevatorVO> listSpecification(@Param("id") Long id, @Param("bargainId") Long bargainId);

    List<SpecificationVO> listByQuotationNoAndVersion(SpecificationQueryBO tqSpecification);

    List<ElevatorExportVO> listElevatorExport(List<Long> quotationIdList);

    List<QuotationContractVo> getQuotation4Contract(QuotationContractBo quotationContractBo);
}
