package com.ruoyi.project.business.controller.quotation;

import com.ruoyi.common.enums.FileBuzType;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.business.domain.TbFile;
import com.ruoyi.project.business.domain.TqSpecification;
import com.ruoyi.project.business.domain.bo.quotation.SpecificationQueryBO;
import com.ruoyi.project.business.domain.vo.quotation.SpecificationVO;
import com.ruoyi.project.business.service.ITbFileService;
import com.ruoyi.project.business.service.quotation.ITqSpecificationService;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-05-10
 */
@RestController
@RequestMapping("/business/specification")
public class TqSpecificationController extends BaseController
{
    @Autowired
    private ITqSpecificationService tqSpecificationService;
    @Resource
    private ITbFileService tbFileService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:specification:list')")
    @GetMapping("/list")
    public TableDataInfo list(SpecificationQueryBO tqSpecification) {
        startPage();
        List<SpecificationVO> list = tqSpecificationService.selectTqSpecificationList(tqSpecification);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:specification:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TqSpecification tqSpecification)
    {
        // List<SpecificationVO> list = tqSpecificationService.selectTqSpecificationList(tqSpecification);
        // ExcelUtil<SpecificationVO> util = new ExcelUtil<TqSpecification>(TqSpecification.class);
        // util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:specification:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tqSpecificationService.selectTqSpecificationById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:specification:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TqSpecification tqSpecification)
    {
        return toAjax(tqSpecificationService.insertTqSpecification(tqSpecification));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:specification:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TqSpecification tqSpecification)
    {
        return toAjax(tqSpecificationService.updateTqSpecification(tqSpecification));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:specification:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tqSpecificationService.deleteTqSpecificationByIds(ids));
    }

    /**
     * 根据报价id获取规格列表
     */
    @GetMapping("/listByQuotationId/{quotationId}")
    public AjaxResult listByQuotationId(@PathVariable("quotationId") Long quotationId) {
        SpecificationQueryBO tqSpecification = new SpecificationQueryBO();
        tqSpecification.setQuotationId(quotationId);
        return success(tqSpecificationService.selectTqSpecificationList(tqSpecification));
    }

    /**
     * 土建出图 - 根据报价no和版本获取规格详细列表
     */
    @GetMapping("/listByQuotationNoVersion")
    public AjaxResult listMoreByQuotationNoAndVersion(SpecificationQueryBO tqSpecification) {
        return success(tqSpecificationService.listMoreByQuotationNoAndVersion(tqSpecification));
    }

    @PostMapping("/uploadSpecCivilImage")
    public AjaxResult uploadSpecCivilImage(@RequestBody TbFile tbFile)
    {
        return tbFileService.saveOrUpdateFile(tbFile.getFilePath(), tbFile.getBusinessId(), FileBuzType.SPECIFICATION_CIVIL_IMG.getType())
                ? AjaxResult.success(): AjaxResult.error();
    }
}
